# -*- coding: utf-8 -*-
from typing import Iterator as _Iterator
from typing import List as _List
from typing import Optional as _Optional

from pydantic import BaseModel as _BaseModel
from pydantic import Field as _Field


class Precipitation(_BaseModel):
    type_ext: _Optional[int]
    intensity: int
    amount: float
    type: int


class HPa(_BaseModel):
    max: int
    min: int


class MmHgAtm(_BaseModel):
    max: int
    min: int


class InHg(_BaseModel):
    max: float
    min: float


class Pressure(_BaseModel):
    h_pa: HPa
    mm_hg_atm: MmHgAtm
    in_hg: InHg


class Percent(_BaseModel):
    max: int
    min: int
    avg: int


class Humidity(_BaseModel):
    percent: Percent


class Description(_BaseModel):
    full: str


class Cloudiness(_BaseModel):
    type: int
    percent: int


class Date(_BaseModel):
    utc: str = _Field(..., alias="UTC")
    local: str
    time_zone_offset: int
    unix: int


class Radiation(_BaseModel):
    max: _Optional[int]
    max_index: _Optional[int]


class Max(_BaseModel):
    c: float = _Field(..., alias="C")
    f: float = _Field(..., alias="F")


class Min(_BaseModel):
    c: float = _Field(..., alias="C")
    f: float = _Field(..., alias="F")


class Comfort(_BaseModel):
    max: Max
    min: Min


class Max1(_BaseModel):
    c: float = _Field(..., alias="C")
    f: float = _Field(..., alias="F")


class Min1(_BaseModel):
    c: float = _Field(..., alias="C")
    f: float = _Field(..., alias="F")


class Water(_BaseModel):
    max: Max1
    min: Min1


class Max2(_BaseModel):
    c: float = _Field(..., alias="C")
    f: float = _Field(..., alias="F")


class Min2(_BaseModel):
    c: float = _Field(..., alias="C")
    f: float = _Field(..., alias="F")


class Avg(_BaseModel):
    c: float = _Field(..., alias="C")
    f: float = _Field(..., alias="F")


class Air(_BaseModel):
    max: Max2
    min: Min2
    avg: Avg


class Temperature(_BaseModel):
    comfort: Comfort
    water: Water
    air: Air


class Max3(_BaseModel):
    km_h: int
    m_s: int
    mi_h: int


class Min3(_BaseModel):
    km_h: int
    m_s: int
    mi_h: int


class Avg1(_BaseModel):
    km_h: _Optional[int]
    m_s: _Optional[int]
    mi_h: _Optional[int]


class Speed(_BaseModel):
    max: Max3
    min: Min3
    avg: Avg1


class Max4(_BaseModel):
    degree: _Optional[int]
    scale_8: _Optional[int]


class Min4(_BaseModel):
    degree: _Optional[int]
    scale_8: _Optional[int]


class Avg2(_BaseModel):
    degree: _Optional[int]
    scale_8: _Optional[int]


class Direction(_BaseModel):
    max: Max4
    min: Min4
    avg: Avg2


class Wind(_BaseModel):
    speed: Speed
    direction: Direction


class ModelItem(_BaseModel):
    precipitation: Precipitation
    pressure: Pressure
    humidity: Humidity
    gm: int
    description: Description
    cloudiness: Cloudiness
    date: Date
    phenomenon: _Optional[int]
    radiation: Radiation
    city: int
    kind: _Optional[str]
    storm: bool
    temperature: Temperature
    wind: Wind
    icon: str


class Model(_BaseModel):
    __root__: _List[ModelItem]

    def __iter__(self) -> _Iterator[ModelItem]:  # type: ignore
        return iter(self.__root__)

    def __getitem__(self, item: int) -> ModelItem:
        return self.__root__[item]



# -*- coding: utf-8 -*-
from typing import Iterator as _Iterator
from typing import List as _List
from typing import Optional as _Optional

from pydantic import BaseModel as _BaseModel
from pydantic import Field as _Field


class Precipitation(_BaseModel):
    type_ext: _Optional[int]
    intensity: int
    correction: _Optional[bool]
    amount: _Optional[float]
    duration: int
    type: int


class Pressure(_BaseModel):
    h_pa: int
    mm_hg_atm: int
    in_hg: float


class Humidity(_BaseModel):
    percent: _Optional[int]


class Direction(_BaseModel):
    degree: _Optional[int]
    scale_8: _Optional[int]


class Speed(_BaseModel):
    km_h: int
    m_s: int
    mi_h: int


class Wind(_BaseModel):
    direction: Direction
    speed: Speed


class Cloudiness(_BaseModel):
    type: int
    percent: int


class Date(_BaseModel):
    utc: str = _Field(..., alias="UTC")
    time_zone_offset: int
    local: str
    hr_to_forecast: _Optional[int]
    unix: int


class Radiation(_BaseModel):
    uvb_index: _Optional[int]
    uvb: _Optional[int] = _Field(..., alias="UVB")


class Comfort(_BaseModel):
    c: float = _Field(..., alias="C")
    f: float = _Field(..., alias="F")


class Water(_BaseModel):
    c: float = _Field(..., alias="C")
    f: float = _Field(..., alias="F")


class Air(_BaseModel):
    c: float = _Field(..., alias="C")
    f: float = _Field(..., alias="F")


class Temperature(_BaseModel):
    comfort: Comfort
    water: Water
    air: Air


class Description(_BaseModel):
    full: str


class ModelItem(_BaseModel):
    precipitation: Precipitation
    pressure: Pressure
    humidity: Humidity
    icon: str
    gm: int
    wind: Wind
    cloudiness: Cloudiness
    date: Date
    phenomenon: _Optional[int]
    radiation: Radiation
    city: int
    kind: str
    storm: bool
    temperature: Temperature
    description: Description


class Model(_BaseModel):
    __root__: _List[ModelItem]

    def __iter__(self) -> _Iterator[ModelItem]:  # type: ignore
        return iter(self.__root__)

    def __getitem__(self, item: int) -> ModelItem:
        return self.__root__[item]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pygismeteo_base', 'pygismeteo_base.models']

package_data = \
{'': ['*']}

install_requires = \
['pydantic>=1.8.2,<2.0.0']

setup_kwargs = {
    'name': 'pygismeteo-base',
    'version': '2.2.0',
    'description': 'Base for pygismeteo and aiopygismeteo',
    'long_description': '# pygismeteo-base\n\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://github.com/monosans/pygismeteo-base/blob/main/LICENSE)\n\nБаза для [pygismeteo](https://github.com/monosans/pygismeteo) и [aiopygismeteo](https://github.com/monosans/aiopygismeteo).\n',
    'author': 'monosans',
    'author_email': 'hsyqixco@protonmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/monosans/pygismeteo-base',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6.2,<4.0.0',
}


setup(**setup_kwargs)
